==> owncloud-10.4.0.zip: owncloud/apps/files/l10n/tr.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Depolama geçici olarak müsait değil",
    "Storage invalid" : "Depolama geçersiz",
    "Unknown error" : "Bilinmeyen hata",
    "All files" : "Tüm dosyalar",
    "File could not be found" : "Dosya bulunamadı",
    "Home" : "Ev",
    "Close" : "Kapat",
    "Favorites" : "Sık kullanılanlar",
    "Upload timeout for file \"{file}\"" : "\"{file}\" dosyası için yükleme zaman aşımı",
    "Unknown error \"{error}\" uploading file \"{file}\"" : "\"{file}\" dosyası yüklenirken bilinmeyen hata \"{error}\"",
    "Could not create folder \"{dir}\"" : "\"{dir}\" klasörü oluşturulamadı",
    "Upload cancelled." : "Yükleme iptal edildi.",
    "The file {file} already exists" : "{file} dosyası zaten mecut",
    "Processing files..." : "Dosyalar işleniyor...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "{filename} bir dizin veya 0 bayt olduğundan yüklenemedi",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Yeterince boş alan yok. Gönderdiğiniz boyut {size1} ancak {size2} alan mevcut",
    "Target folder \"{dir}\" does not exist any more" : "\"{dir}\" hedef klasörü artık mevcut değil",
    "Target folder does not exist any more" : "Hedef klasör artık mevcut değil",
    "The file {file} is currently locked, please try again later" : "{file} dosyası şu anda kilitli, lütfen daha sonra tekrar deneyin",
    "Not enough free space" : "Yeterli boş alan yok",
    "Uploading..." : "Yükleniyor...",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} / {totalSize} ({bitrate})",
    "Error when assembling chunks, status code {status}" : "Parçalar birleştirilirken hata oluştu, durum kodu {status}",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Dosya yükleme işlemi sürüyor. Şu anda sayfadan ayrılmak yükleme işlemini iptal edecek.",
    "Actions" : "Eylemler",
    "Download" : "İndir",
    "Rename" : "Yeniden adlandır",
    "Delete" : "Sil",
    "Disconnect storage" : "Depolama bağlantısını kes",
    "Unshare" : "Paylaşmayı Kaldır",
    "Could not load info for file \"{file}\"" : "\"{file}\" dosyası için bilgi yüklenemedi",
    "Files" : "Dosyalar",
    "Details" : "Ayrıntılar",
    "Select" : "Seç",
    "Pending" : "Bekliyor",
    "Unable to determine date" : "Tarih tespit edilemedi",
    "Invalid path" : "Geçersiz yol",
    "This operation is forbidden" : "Bu işlem yasak",
    "This directory is unavailable, please check the logs or contact the administrator" : "Bu dizine yazılamıyor, lütfen günlüğü kontrol edin veya yönetici ile iletişime geçin",
    "group" : "grup",
    "Remote share" : "Uzak paylaşım",
    "via" : "ile",
    "Could not move \"{file}\", target exists" : "\"{file}\" taşınamadı, hedef mevcut",
    "Could not move \"{file}\" because either the file or the target are locked." : "Dosya veya hedef kilitli olduğu için \"{file}\" taşınamadı.",
    "Could not move \"{file}\": {message}" : "\"{file}\" taşınamadı: {message}",
    "Could not move \"{file}\"" : "\"{file}\" taşınamadı",
    "{newName} already exists" : "{newName} zaten mevcut",
    "Could not rename \"{fileName}\", it does not exist any more" : "\"{fileName}\" adlandırılamadı, artık mevcut değil",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{targetName}\" ismi zaten \"{dir}\" klasöründe kullanılıyor. Lütfen farklı bir isim seçin.",
    "The file \"{fileName}\" is locked and can not be renamed." : "\"{fileName}\" dosyası kilitli ve yeniden adlandırılamıyor.",
    "Could not rename \"{fileName}\"" : "\"{fileName}\" adlandırılamadı",
    "Could not create file \"{file}\"" : "\"{file}\" dosyası oluşturulamadı",
    "Could not create file \"{file}\" because it already exists" : "\"{file}\" dosyası zaten mevcut olduğundan oluşturulamadı",
    "Could not create folder \"{dir}\" because it already exists" : "\"{dir}\" klasörü zaten mevcut olduğundan oluşturulamadı",
    "The file \"{fileName}\" is locked and cannot be deleted." : "\"{fileName}\" dosyası kilitli ve silinemiyor.",
    "Error deleting file \"{fileName}\"." : "\"{fileName}\" dosyası silinirken hata.",
    "No entries in this folder match {filter}" : "Bu klasördeki hiçbir kayıt {filter} ile eşleşmiyor",
    "Name" : "İsim",
    "Size" : "Boyut",
    "Modified" : "Değiştirilme",
    "_%n folder_::_%n folders_" : ["%n klasör","%n klasör"],
    "_%n file_::_%n files_" : ["%n dosya","%n dosya"],
    "{dirs} and {files}" : "{dirs} ve {files}",
    "_including %n hidden_::_including %n hidden_" : ["gizli %n dahil","gizli %n dahil"],
    "You don’t have permission to upload or create files here" : "Buraya dosya yükleme veya oluşturma izniniz yok",
    "_Uploading %n file_::_Uploading %n files_" : ["%n dosya yükleniyor","%n dosya yükleniyor"],
    "New" : "Yeni",
    "Unknown user" : "Bilinmeyen kullanıcı",
    "Lock status" : "Kilit durumu",
    "This resource is locked. Click to see more details." : "Bu kaynak kilitli. Daha fazla ayrıntı görmek için tıklayın.",
    "\"{name}\" is an invalid file name." : "\"{name}\" geçersiz bir dosya adı.",
    "File name cannot be empty." : "Dosya adı boş olamaz.",
    "File name cannot contain \"/\"." : "Dosya adı \"/\" içeremez.",
    "\"{name}\" has a forbidden file type/extension." : "\"{name}\" adlı dosyada yasak dosya türü/uzantısı var.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} depolama alanı dolu, artık dosyalar güncellenmeyecek yada eşitlenmeyecek.",
    "Your storage is full, files can not be updated or synced anymore!" : "Depolama alanınız dolu, artık dosyalar güncellenmeyecek veya eşitlenmeyecek.",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : " {owner} depolama alanı neredeyse dolu ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Depolama alanınız neredeyse dolu (%{usedSpacePercent})",
    "_matches '{filter}'_::_match '{filter}'_" : ["'{filter}' ile eşleşiyor","'{filter}' ile eşleşiyor"],
    "{owner} has locked this resource via {path}" : "{owner} bu kaynağı {path} yoluyla kilitledi",
    "Could not unlock, please contact the lock owner {owner}" : "Kilidi kaldırılamadı, lütfen kilit sahibiyle iletişime geçin {owner}",
    "Unlock failed with status {status}" : "Kilitleme {status} durumu ile başarısız oldu",
    "Locks" : "Kilitler",
    "Resource is not locked" : "Kaynak kilitli değil",
    "Path" : "Yol",
    "_%n byte_::_%n bytes_" : ["%n bayt","%n bayt"],
    "Favorited" : "Sık kullanılanlara eklendi",
    "Favorite" : "Sık kullanılan",
    "Private link:  Only people who have access to the file/folder can use it. Use it as a permanent link for yourself or to point others to files within shares" : "Özel bağlantı: Yalnızca dosyaya/klasöre erişimi olan kişiler kullanabilir. Bunu kendiniz için kalıcı bir bağlantı olarak veya başkalarını paylaşımlardaki dosyalara yönlendirmek için kullanın",
    "Folder" : "Klasör",
    "New folder" : "Yeni klasör",
    "{newname} already exists" : "{newname} zaten mevcut",
    "Upload" : "Yükle",
    "An error occurred while trying to update the tags" : "Etiketler güncellenmeye çalışılırken bir hata oluştu",
    "A new file or folder has been <strong>created</strong>" : "Yeni bir dosya veya klasör <strong>oluşturuldu</strong>",
    "A file or folder has been <strong>changed</strong>" : "Bir dosya veya klasör <strong>değiştirildi</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "<strong>Sık kullanılan dosyalarınızın</strong> oluşturulma ve değiştirilme hakkındaki bildirimleri sınırla <em>(Sadece akışta)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Bir dosya veya klasör <strong>silindi</strong>",
    "A file or folder has been <strong>restored</strong>" : "Bir dosya veya klasör <strong>geri alındı</strong>",
    "You created %1$s" : "%1$s dosyasını oluşturdunuz",
    "%2$s created %1$s" : "%2$s, %1$s dosyasını oluşturdu",
    "%1$s was created in a public folder" : "%1$s herkese açık klasörde oluşturuldu",
    "You changed %1$s" : "%1$s dosyasını değiştirdiniz",
    "%2$s changed %1$s" : "%2$s, %1$s dosyasını değiştirdi",
    "You deleted %1$s" : "%1$s dosyasını sildiniz",
    "%2$s deleted %1$s" : "%2$s, %1$s dosyasını sildi",
    "You restored %1$s" : "%1$s ögesini geri aldınız",
    "%2$s restored %1$s" : "%2$s, %1$s ögesini geri aldı",
    "Changed by %2$s" : "%2$s tarafından değiştirildi",
    "Deleted by %2$s" : "%2$s tarafından silindi",
    "Restored by %2$s" : "%2$s tarafından geri yüklendi",
    "You don't have permissions to access this file/folder - Please contact the owner to share it with you." : "Bu dosyaya/klasöre erişim izniniz yok - Lütfen sizinle paylaşmak için sahibiyle bağlantı kurun.",
    "Upload (max. %s)" : "Yükle (azami: %s)",
    "Settings" : "Ayarlar",
    "Show hidden files" : "Gizli dosyaları göster",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Dosyalarınıza WebDAV ile erişmek için <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">bu adresi kullanın</a>",
    "No files in here" : "Burada hiç dosya yok",
    "Upload some content or sync with your devices!" : "Bir şeyler yükleyin veya aygıtlarınızla eşitleyin!",
    "No entries found in this folder" : "Bu klasörde hiçbir girdi bulunamadı",
    "Select all" : "Tümünü seç",
    "Upload too large" : "Yükleme çok büyük",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Yüklemeye çalıştığınız dosyalar bu sunucudaki azami yükleme boyutunu aşıyor.",
    "No favorites" : "Sık kullanılan öge yok.",
    "Files and folders you mark as favorite will show up here" : "Sık kullanılan olarak işaretlediğiniz dosya ve klasörler burada gösterilecek",
    "Text file" : "Metin dosyası",
    "New text file.txt" : "Yeni metin dosyası.txt"
},
"nplurals=2; plural=(n > 1);");

==> owncloud-10.4.1.zip: owncloud/apps/files/l10n/tr.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Depolama geçici olarak müsait değil",
    "Storage invalid" : "Depolama geçersiz",
    "Unknown error" : "Bilinmeyen hata",
    "All files" : "Tüm dosyalar",
    "File could not be found" : "Dosya bulunamadı",
    "Home" : "Ev",
    "Close" : "Kapat",
    "Favorites" : "Sık kullanılanlar",
    "Upload timeout for file \"{file}\"" : "\"{file}\" dosyası için yükleme zaman aşımı",
    "Unknown error \"{error}\" uploading file \"{file}\"" : "\"{file}\" dosyası yüklenirken bilinmeyen hata \"{error}\"",
    "Could not create folder \"{dir}\"" : "\"{dir}\" klasörü oluşturulamadı",
    "Upload cancelled." : "Yükleme iptal edildi.",
    "The file {file} already exists" : "{file} dosyası zaten mecut",
    "Processing files..." : "Dosyalar işleniyor...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "{filename} bir dizin veya 0 bayt olduğundan yüklenemedi",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Yeterince boş alan yok. Gönderdiğiniz boyut {size1} ancak {size2} alan mevcut",
    "You don’t have permission to upload or create files here" : "Buraya dosya yükleme veya oluşturma izniniz yok",
    "Target folder \"{dir}\" does not exist any more" : "\"{dir}\" hedef klasörü artık mevcut değil",
    "Target folder does not exist any more" : "Hedef klasör artık mevcut değil",
    "The file {file} is currently locked, please try again later" : "{file} dosyası şu anda kilitli, lütfen daha sonra tekrar deneyin",
    "Not enough free space" : "Yeterli boş alan yok",
    "Uploading..." : "Yükleniyor...",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} / {totalSize} ({bitrate})",
    "Error when assembling chunks, status code {status}" : "Parçalar birleştirilirken hata oluştu, durum kodu {status}",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Dosya yükleme işlemi sürüyor. Şu anda sayfadan ayrılmak yükleme işlemini iptal edecek.",
    "Actions" : "Eylemler",
    "Download" : "İndir",
    "Rename" : "Yeniden adlandır",
    "Delete" : "Sil",
    "Disconnect storage" : "Depolama bağlantısını kes",
    "Unshare" : "Paylaşmayı Kaldır",
    "Could not load info for file \"{file}\"" : "\"{file}\" dosyası için bilgi yüklenemedi",
    "Files" : "Dosyalar",
    "Details" : "Ayrıntılar",
    "Select" : "Seç",
    "Pending" : "Bekliyor",
    "Unable to determine date" : "Tarih tespit edilemedi",
    "Invalid path" : "Geçersiz yol",
    "This operation is forbidden" : "Bu işlem yasak",
    "This directory is unavailable, please check the logs or contact the administrator" : "Bu dizine yazılamıyor, lütfen günlüğü kontrol edin veya yönetici ile iletişime geçin",
    "group" : "grup",
    "Remote share" : "Uzak paylaşım",
    "via" : "ile",
    "Could not move \"{file}\", target exists" : "\"{file}\" taşınamadı, hedef mevcut",
    "Could not move \"{file}\" because either the file or the target are locked." : "Dosya veya hedef kilitli olduğu için \"{file}\" taşınamadı.",
    "Could not move \"{file}\": {message}" : "\"{file}\" taşınamadı: {message}",
    "Could not move \"{file}\"" : "\"{file}\" taşınamadı",
    "{newName} already exists" : "{newName} zaten mevcut",
    "Could not rename \"{fileName}\", it does not exist any more" : "\"{fileName}\" adlandırılamadı, artık mevcut değil",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{targetName}\" ismi zaten \"{dir}\" klasöründe kullanılıyor. Lütfen farklı bir isim seçin.",
    "The file \"{fileName}\" is locked and can not be renamed." : "\"{fileName}\" dosyası kilitli ve yeniden adlandırılamıyor.",
    "Could not rename \"{fileName}\"" : "\"{fileName}\" adlandırılamadı",
    "Could not create file \"{file}\"" : "\"{file}\" dosyası oluşturulamadı",
    "Could not create file \"{file}\" because it already exists" : "\"{file}\" dosyası zaten mevcut olduğundan oluşturulamadı",
    "Could not create folder \"{dir}\" because it already exists" : "\"{dir}\" klasörü zaten mevcut olduğundan oluşturulamadı",
    "The file \"{fileName}\" is locked and cannot be deleted." : "\"{fileName}\" dosyası kilitli ve silinemiyor.",
    "Error deleting file \"{fileName}\"." : "\"{fileName}\" dosyası silinirken hata.",
    "No entries in this folder match {filter}" : "Bu klasördeki hiçbir kayıt {filter} ile eşleşmiyor",
    "Name" : "İsim",
    "Size" : "Boyut",
    "Modified" : "Değiştirilme",
    "_%n folder_::_%n folders_" : ["%n klasör","%n klasör"],
    "_%n file_::_%n files_" : ["%n dosya","%n dosya"],
    "{dirs} and {files}" : "{dirs} ve {files}",
    "_including %n hidden_::_including %n hidden_" : ["gizli %n dahil","gizli %n dahil"],
    "_Uploading %n file_::_Uploading %n files_" : ["%n dosya yükleniyor","%n dosya yükleniyor"],
    "New" : "Yeni",
    "Unknown user" : "Bilinmeyen kullanıcı",
    "Lock status" : "Kilit durumu",
    "This resource is locked. Click to see more details." : "Bu kaynak kilitli. Daha fazla ayrıntı görmek için tıklayın.",
    "\"{name}\" is an invalid file name." : "\"{name}\" geçersiz bir dosya adı.",
    "File name cannot be empty." : "Dosya adı boş olamaz.",
    "File name cannot contain \"/\"." : "Dosya adı \"/\" içeremez.",
    "\"{name}\" has a forbidden file type/extension." : "\"{name}\" adlı dosyada yasak dosya türü/uzantısı var.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} depolama alanı dolu, artık dosyalar güncellenmeyecek yada eşitlenmeyecek.",
    "Your storage is full, files can not be updated or synced anymore!" : "Depolama alanınız dolu, artık dosyalar güncellenmeyecek veya eşitlenmeyecek.",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : " {owner} depolama alanı neredeyse dolu ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Depolama alanınız neredeyse dolu (%{usedSpacePercent})",
    "_matches '{filter}'_::_match '{filter}'_" : ["'{filter}' ile eşleşiyor","'{filter}' ile eşleşiyor"],
    "{owner} has locked this resource via {path}" : "{owner} bu kaynağı {path} yoluyla kilitledi",
    "Could not unlock, please contact the lock owner {owner}" : "Kilidi kaldırılamadı, lütfen kilit sahibiyle iletişime geçin {owner}",
    "Unlock failed with status {status}" : "Kilitleme {status} durumu ile başarısız oldu",
    "Locks" : "Kilitler",
    "Resource is not locked" : "Kaynak kilitli değil",
    "Path" : "Yol",
    "_%n byte_::_%n bytes_" : ["%n bayt","%n bayt"],
    "Favorited" : "Sık kullanılanlara eklendi",
    "Favorite" : "Sık kullanılan",
    "Private link:  Only people who have access to the file/folder can use it. Use it as a permanent link for yourself or to point others to files within shares" : "Özel bağlantı: Yalnızca dosyaya/klasöre erişimi olan kişiler kullanabilir. Bunu kendiniz için kalıcı bir bağlantı olarak veya başkalarını paylaşımlardaki dosyalara yönlendirmek için kullanın",
    "Folder" : "Klasör",
    "New folder" : "Yeni klasör",
    "{newname} already exists" : "{newname} zaten mevcut",
    "Upload" : "Yükle",
    "An error occurred while trying to update the tags" : "Etiketler güncellenmeye çalışılırken bir hata oluştu",
    "A new file or folder has been <strong>created</strong>" : "Yeni bir dosya veya klasör <strong>oluşturuldu</strong>",
    "A file or folder has been <strong>changed</strong>" : "Bir dosya veya klasör <strong>değiştirildi</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "<strong>Sık kullanılan dosyalarınızın</strong> oluşturulma ve değiştirilme hakkındaki bildirimleri sınırla <em>(Sadece akışta)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Bir dosya veya klasör <strong>silindi</strong>",
    "A file or folder has been <strong>restored</strong>" : "Bir dosya veya klasör <strong>geri alındı</strong>",
    "You created %1$s" : "%1$s dosyasını oluşturdunuz",
    "%2$s created %1$s" : "%2$s, %1$s dosyasını oluşturdu",
    "%1$s was created in a public folder" : "%1$s herkese açık klasörde oluşturuldu",
    "You changed %1$s" : "%1$s dosyasını değiştirdiniz",
    "%2$s changed %1$s" : "%2$s, %1$s dosyasını değiştirdi",
    "You deleted %1$s" : "%1$s dosyasını sildiniz",
    "%2$s deleted %1$s" : "%2$s, %1$s dosyasını sildi",
    "You restored %1$s" : "%1$s ögesini geri aldınız",
    "%2$s restored %1$s" : "%2$s, %1$s ögesini geri aldı",
    "Changed by %2$s" : "%2$s tarafından değiştirildi",
    "Deleted by %2$s" : "%2$s tarafından silindi",
    "Restored by %2$s" : "%2$s tarafından geri yüklendi",
    "You don't have permissions to access this file/folder - Please contact the owner to share it with you." : "Bu dosyaya/klasöre erişim izniniz yok - Lütfen sizinle paylaşması için sahibiyle bağlantı kurun.",
    "Upload (max. %s)" : "Yükle (azami: %s)",
    "Settings" : "Ayarlar",
    "Show hidden files" : "Gizli dosyaları göster",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Dosyalarınıza WebDAV ile erişmek için <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">bu adresi kullanın</a>",
    "No files in here" : "Burada hiç dosya yok",
    "Upload some content or sync with your devices!" : "Bir şeyler yükleyin veya aygıtlarınızla eşitleyin!",
    "No entries found in this folder" : "Bu klasörde hiçbir girdi bulunamadı",
    "Select all" : "Tümünü seç",
    "Upload too large" : "Yükleme çok büyük",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Yüklemeye çalıştığınız dosyalar bu sunucudaki azami yükleme boyutunu aşıyor.",
    "No favorites" : "Sık kullanılan öge yok.",
    "Files and folders you mark as favorite will show up here" : "Sık kullanılan olarak işaretlediğiniz dosya ve klasörler burada gösterilecek",
    "Text file" : "Metin dosyası",
    "New text file.txt" : "Yeni metin dosyası.txt"
},
"nplurals=2; plural=(n > 1);");
